@@ -1,13 +1,12 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 from doctest import DocTestSuite
 import pickle
 import unittest
 
-import django
 from django.contrib.auth import get_user_model
 from django.db import IntegrityError
-import django.test
+from django.test import RequestFactory
+from django.test import TestCase as DjangoTestCase
+from django.urls import reverse
 
 from django_otp import DEVICE_ID_SESSION_KEY, oath, util
 from django_otp.middleware import OTPMiddleware
@@ -23,30 +22,30 @@ def load_tests(loader, tests, pattern):
     return suite
 
 
-class TestCase(django.test.TestCase):
+class TestCase(DjangoTestCase):
     """
     Utilities for dealing with custom user models.
     """
     @classmethod
     def setUpClass(cls):
-        super(TestCase, cls).setUpClass()
+        super().setUpClass()
 
         cls.User = get_user_model()
         cls.USERNAME_FIELD = cls.User.USERNAME_FIELD
 
-    def create_user(self, username, password):
+    def create_user(self, username, password, **kwargs):
         """
         Try to create a user, honoring the custom user model, if any.
 
         This may raise an exception if the user model is too exotic for our
         purposes.
         """
-        return self.User.objects.create_user(username, password=password)
+        return self.User.objects.create_user(username, password=password, **kwargs)
 
 
 class OTPMiddlewareTestCase(TestCase):
     def setUp(self):
-        self.factory = django.test.RequestFactory()
+        self.factory = RequestFactory()
         try:
             self.alice = self.create_user('alice', 'password')
             self.bob = self.create_user('bob', 'password')
@@ -146,7 +145,7 @@ class LoginViewTestCase(TestCase):
     def setUp(self):
         try:
             self.alice = self.create_user('alice', 'password')
-            self.bob = self.create_user('bob', 'password')
+            self.bob = self.create_user('bob', 'password', is_staff=True)
         except IntegrityError:
             self.skipTest("Unable to create a test user.")
         else:
@@ -154,6 +153,32 @@ class LoginViewTestCase(TestCase):
                 device = user.staticdevice_set.create()
                 device.token_set.create(token=user.get_username())
 
+    def test_admin_login_template(self):
+        response = self.client.get(reverse('admin:login'))
+        self.assertContains(response, 'Username:')
+        self.assertContains(response, 'Password:')
+        self.assertNotContains(response, 'OTP Device:')
+        self.assertContains(response, 'OTP Token:')
+        response = self.client.post(reverse('admin:login'), data={
+            'username': self.bob.get_username(),
+            'password': 'password',
+        })
+        self.assertContains(response, 'Username:')
+        self.assertContains(response, 'Password:')
+        self.assertContains(response, 'OTP Device:')
+        self.assertContains(response, 'OTP Token:')
+
+        device = self.bob.staticdevice_set.get()
+        token = device.token_set.get()
+        response = self.client.post(reverse('admin:login'), data={
+            'username': self.bob.get_username(),
+            'password': 'password',
+            'otp_device': device.persistent_id,
+            'otp_token': token.token,
+            'next': '/',
+        })
+        self.assertRedirects(response, '/')
+
     def test_authenticate(self):
         device = self.alice.staticdevice_set.get()
         token = device.token_set.get()
