@@ -1,5 +1,3 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 from django.conf.urls import url
 from django.contrib import admin
 import django.contrib.auth.views
@@ -7,6 +5,12 @@ from django.http import HttpResponse
 from django.views.generic.base import View
 
 import django_otp.views
+from django_otp.admin import OTPAdminSite
+
+
+otp_admin_site = OTPAdminSite(OTPAdminSite.name)
+for model_cls, model_admin in admin.site._registry.items():
+    otp_admin_site.register(model_cls, model_admin.__class__)
 
 
 class HomeView(View):
@@ -18,5 +22,5 @@ urlpatterns = [
     url(r'^$', HomeView.as_view()),
     url(r'^login/$', django_otp.views.LoginView.as_view()),
     url(r'^logout/$', django.contrib.auth.views.LogoutView.as_view()),
-    url(r'^admin/', admin.site.urls),
+    url(r'^admin/', otp_admin_site.urls),
 ]
